@@ -55,7 +55,9 @@ _CLOUDEVENT_MIME_TYPE = "application/cloudevents+json"
 
 _DAPR_BINDINGS = "bindings"
 _DAPR_PUBSUB = "pubsub"
-
+global DAPR_WORKMODE  
+_DAPR_SIDECAR_MODE = "sidecar"
+_DAPR_STANDALONE_MODE = "standalone"
 
 class _LoggingHandler(io.TextIOWrapper):
     """Logging replacement for stdout and stderr in GCF Python 3.7."""
@@ -367,8 +369,9 @@ def _configure_dapr_app(_app, function, ctx: FunctionContext):
                 print("binding {}".format(input.componentName))
             elif type == _DAPR_PUBSUB:
                 _app.subscribe(topic=input.uri, pubsub_name=input.componentName)(function)
-                key = _app._servicer._topic_map.keys()
-                _app._servicer._topic_map["{}:{}:{}".format(input.componentName,input.uri,input.uri)]=_app._servicer._topic_map.pop(list(key)[0])
+                if DAPR_WORKMODE == _DAPR_STANDALONE_MODE:
+                    key = _app._servicer._topic_map.keys()
+                    _app._servicer._topic_map["{}:{}:{}".format(input.componentName,input.uri,input.uri)]=_app._servicer._topic_map.pop(list(key)[0])
                 print("sub topic {}, pubsub name {}".format(input.uri, input.componentName))
             else:
                 raise InvalidFuncContextInputType(
@@ -409,6 +412,7 @@ class LazyWSGIApp:
     """
 
     def __init__(self, target=None, source=None, signature_type=None):
+        global DAPR_WORKMODE
         # Support HTTP frameworks which support WSGI callables.
         # Note: this ability is currently broken in Gunicorn 20.0, and
         # environment variables should be used for configuration instead:
@@ -419,7 +423,7 @@ class LazyWSGIApp:
 
         # Placeholder for the app which will be initialized on first call
         self.app = None
-
+        DAPR_WORKMODE = os.getenv("APP_PROTOCOL",_DAPR_SIDECAR_MODE)
     def __call__(self, *args, **kwargs):
         if not self.app:
             ff = os.getenv("FUNC_CONTEXT", "")
@@ -434,16 +438,15 @@ class LazyWSGIApp:
                     self.app = create_app(self.target, self.source, self.signature_type)
                 elif str(_ctx.runtime).lower() == ASYNC:
                     signature_type = "of"
-                    print(datetime.now())
+                    print(datetime.now(),flush=True)
                     print("start dapr app")
                     self.app = create_dapr_app(self.target, self.source, self.signature_type, _ctx)
                     print("start dapr service")
-                    print(datetime.now())
+                    print(datetime.now(),flush=True)
         return self.app(*args, **kwargs)
 
 
-print("start")
-print(datetime.now())
+
 app = LazyWSGIApp()
 
 
