@@ -22,7 +22,7 @@ from functions_framework._of import create_dapr_server
 
 _FUNC_CTX = dict()
 KNATIVE_FUNC = "Knative"
-ASYNC = "OpenFuncAsync"
+ASYNC = "Async"
 
 
 @click.command()
@@ -39,6 +39,7 @@ ASYNC = "OpenFuncAsync"
 @click.option("--debug", envvar="DEBUG", is_flag=True)
 @click.option("--dry-run", envvar="DRY_RUN", is_flag=True)
 def _cli(target, source, signature_type, host, port, debug, dry_run):
+    grpc_host = os.getenv("DAPR_HOST","127.0.0.1")
     ff = os.getenv("FUNC_CONTEXT", "")
     if signature_type == "http" and ff == "":
         print("start http app")
